==> hinemos-2.1.0_src.tar.gz: hinemos-2.1.0_src/Agent/src/com/clustercontrol/agent/util/EjbConnectionManager.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.agent.util;

import java.util.Properties;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.jnp.interfaces.NamingContext;

import com.clustercontrol.repository.ejb.session.RepositoryController;
import com.clustercontrol.repository.ejb.session.RepositoryControllerHome;


/**
 * EJBȤΥͥ륯饹
 * RepositoryControllerEJBƤӽФΥإ
 * @version $Revision: 1.6 $
 * @since 1.0.0
 */
public class EjbConnectionManager {
    
	private Properties m_props = null;

	private NamingContext m_con = null;

	//
	static private Log log = LogFactory.getLog(EjbConnectionManager.class);

	/**
	 * 󥹥ȥ饯
	 * @param propץѥƥե
	 */
	public EjbConnectionManager(Properties prop) {
		m_props = prop;
	}
	
	/**
	 * RepositoryCollectorޤ
	 * @returnRepositoryCollector
	 */
	public synchronized RepositoryController getRepositoryController() throws Exception {

		try {
			if(m_con != null)
				LoginManager.getContextManager(m_props).logout();
			m_con = LoginManager.getContextManager(m_props).getNamingContext();
			
			RepositoryControllerHome home = (RepositoryControllerHome) m_con
		    	.lookup(RepositoryControllerHome.JNDI_NAME);
			return home.create();
		} catch (Exception e) {
			log.error(e);
			LoginManager.getContextManager(m_props).logout();
			m_con = null;
			throw e;
		}
	}
}

==> hinemos-2.1.1_src.tar.gz: hinemos-2.1.1_src/Agent/src/com/clustercontrol/agent/util/EjbConnectionManager.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.agent.util;

import java.util.Properties;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.jnp.interfaces.NamingContext;

import com.clustercontrol.repository.ejb.session.RepositoryController;
import com.clustercontrol.repository.ejb.session.RepositoryControllerHome;


/**
 * EJBとのコネクションを管理するクラス
 * RepositoryController　EJBを呼び出すためのヘルパ
 * @version $Revision: 1.1.1.1 $
 * @since 1.0.0
 */
public class EjbConnectionManager {
    
	private Properties m_props = null;

	private NamingContext m_con = null;

	//ロガー
	static private Log log = LogFactory.getLog(EjbConnectionManager.class);

	/**
	 * コンストラクタ
	 * @param prop　プロパティファイル情報
	 */
	public EjbConnectionManager(Properties prop) {
		m_props = prop;
	}
	
	/**
	 * RepositoryCollectorを取得します。
	 * @return　RepositoryCollector
	 */
	public synchronized RepositoryController getRepositoryController() throws Exception {

		try {
			if(m_con != null)
				LoginManager.getContextManager(m_props).logout();
			m_con = LoginManager.getContextManager(m_props).getNamingContext();
			
			RepositoryControllerHome home = (RepositoryControllerHome) m_con
		    	.lookup(RepositoryControllerHome.JNDI_NAME);
			return home.create();
		} catch (Exception e) {
			log.error(e);
			LoginManager.getContextManager(m_props).logout();
			m_con = null;
			throw e;
		}
	}
}
